"""
COntains version information for the package
"""

__author__ = "nomike Postmann"
__copyright__ = "Copyright 2024 nomike Postmann"
__email__ = "nomike@nomike.com"
__license__ = "MIT"
__title__ = "stldim"
__version__ = "0.3.1"

__str__ = f'{__title__} v{__version__} by {__author__} <{__email__}>'
